# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

from meta.templatetags.meta import *  # NOQA  # nopyflakes


@register.simple_tag
def generic_prop(namespace, name, value):
    """
    Generic property setter that allows to create custom namespaced meta:
    e.g.: fb:profile_id.
    """
    return '<meta property="%s:%s" content="%s">' % (namespace, name, value)


@register.simple_tag
def googleplus_scope(value):
    """
    This is meant to be used as attribute to html / body or other tags to
    define schema.org type.
    """
    return ' itemscope itemtype="http://schema.org/%s" ' % value



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

from django.conf import settings as django_settings

DEFAULT_IMAGE = getattr(django_settings, 'META_DEFAULT_IMAGE', False)
DEFAULT_TYPE = getattr(django_settings, 'META_SITE_TYPE', False)
FB_TYPE = getattr(django_settings, 'META_FB_TYPE', False)
FB_APPID = getattr(django_settings, 'META_FB_APPID', False)
FB_PROFILE_ID = getattr(django_settings, 'META_FB_PROFILE_ID', False)
FB_PUBLISHER = getattr(django_settings, 'META_FB_PUBLISHER', False)
FB_AUTHOR_URL = getattr(django_settings, 'META_FB_AUTHOR_URL', False)
TWITTER_TYPE = getattr(django_settings, 'META_TWITTER_TYPE', False)
TWITTER_SITE = getattr(django_settings, 'META_TWITTER_SITE', False)
TWITTER_AUTHOR = getattr(django_settings, 'META_TWITTER_AUTHOR', False)
GPLUS_TYPE = getattr(django_settings, 'META_GPLUS_TYPE', False)
GPLUS_AUTHOR = getattr(django_settings, 'META_GPLUS_AUTHOR', False)
